@@ -83,7 +83,7 @@ void QBluetoothServiceDiscoveryAgentPrivate::start(const QBluetoothAddress &addr
 {
     Q_Q(QBluetoothServiceDiscoveryAgent);
 
-    if (!ensureAndroidPermission(BluetoothPermission::Connect)) {
+    if (!ensureAndroidPermission(QBluetoothPermission::Access)) {
         qCWarning(QT_BT_ANDROID) << "Service discovery start() failed due to missing permissions";
         error = QBluetoothServiceDiscoveryAgent::MissingPermissionsError;
         errorString = QBluetoothServiceDiscoveryAgent::tr(
@@ -137,8 +137,8 @@ void QBluetoothServiceDiscoveryAgentPrivate::start(const QBluetoothAddress &addr
                                << ")" << address.toString() ;
 
         //Minimal discovery uses BluetoothDevice.getUuids()
-        QJniObject parcelUuidArray =
-                remoteDevice.callMethod<QtJniTypes::ParcelUuidArray>("getUuids");
+        const QJniArray parcelUuidArray =
+                remoteDevice.callMethod<QtJniTypes::ParcelUuid[]>("getUuids");
 
         if (!parcelUuidArray.isValid()) {
             if (singleDevice) {
@@ -400,7 +400,7 @@ void QBluetoothServiceDiscoveryAgentPrivate::populateDiscoveredServices(const QB
         if (!uuidFilter.isEmpty()) {
             bool match = uuidFilter.contains(serviceInfo.serviceUuid());
             match |= uuidFilter.contains(QBluetoothSocketPrivateAndroid::reverseUuid(serviceInfo.serviceUuid()));
-            for (const auto &uuid : qAsConst(uuidFilter)) {
+            for (const auto &uuid : std::as_const(uuidFilter)) {
                 match |= serviceInfo.serviceClassUuids().contains(uuid);
                 match |= serviceInfo.serviceClassUuids().contains(QBluetoothSocketPrivateAndroid::reverseUuid(uuid));
             }
